@@ -55,11 +55,11 @@ def compile_tex(config, output_dir=None, args=[], stylesheet=None):
             # Raise the exception
             raise exceptions.TectonicError(logfile)
 
+    # Activate the showyourwork conda environment
+    conda_activate = open(paths.user().flags / "SYW__CONDA", "r").read()
+
     get_stdout(
-        ["tectonic"]
-        + args
-        + force_args
-        + config["user_args"]
-        + [paths.user().repo / config["ms_tex"]],
+        f"{conda_activate} tectonic {' '.join(args)} {' '.join(force_args)} {' '.join(config['user_args'])} {paths.user().repo / config['ms_tex']}",
+        shell=True,
         callback=callback,
     )
