@@ -326,7 +326,7 @@ class Zenodo:
                 logger.debug(r.text)
 
         # No dice
-        logger.warn(f"User is not authenticated to edit {self.doi}.")
+        logger.warning(f"User is not authenticated to edit {self.doi}.")
         cache_file_false.touch()
         return False
 
@@ -453,7 +453,7 @@ class Zenodo:
         for entry in data:
 
             logger.debug(
-                f"Inspecting candidate file `{entry['filename']}` with hash `{file.name}`..."
+                f"Inspecting candidate file `{entry['filename']}` with hash `{rule_hashes.get(rule_name, None)}`..."
             )
 
             if (
@@ -506,7 +506,7 @@ class Zenodo:
 
                 # Keep looking in this deposit for a file with the right name
                 logger.debug(
-                    "Cache miss for file {entry['filename']}. Skipping..."
+                    f"Cache miss for file {entry['filename']}. Skipping..."
                 )
 
         # This is caught in the enclosing scope and treated as a cache miss
@@ -833,7 +833,7 @@ class Zenodo:
             },
         )
         if r.status_code > 204:
-            logger.warn(
+            logger.warning(
                 f"{self.service} authentication failed. Unable to upload cache for rule {rule_name}."
             )
             try:
@@ -851,7 +851,7 @@ class Zenodo:
         if len(data):
             data = data[0]
         else:
-            logger.warn(
+            logger.warning(
                 f"{self.service} authentication failed. Unable to upload cache for rule {rule_name}."
             )
             return
